@@ -7,7 +7,7 @@ from dcclog.handlers import (
     FileHandler,
     TimedRotatingFileHandler,
 )
-from dcclog.logger import default_config, getLogger
+from dcclog.logger import basicConfig, default_config, getLogger
 from dcclog.reader import read_log
 from dcclog.utils import b2str, from_json, str2b, to_json
 from dcclog.wrapper import log
@@ -24,6 +24,7 @@ __all__ = [
     "ConsoleHandler",
     "FileHandler",
     "TimedRotatingFileHandler",
+    "basicConfig",
     "default_config",
     "getLogger",
     "read_log",
